Struct GameData
pub struct GameData {
pub path: String,
pub name: String,
pub sprite_sheet: SpriteSheet,
pub tile_map: TileMap,
pub flags: Flags,
pub code: Option<BTreeMap<String, String>>,
}Expand description
This struct is used to load and save the data of the game like sprites and map.
After the game is initialized GameData is only used internal.
Fields
path: StringPath of the game data file.
name: StringName of the game.
sprite_sheet: SpriteSheetHolds the sprites of the game.
tile_map: TileMapHolds the map of the game.
flags: FlagsHolds the flat settings of the map tiles.
code: Option<BTreeMap<String, String>>Used only internal.
Implementations