Function settings_dir
pub fn settings_dir(app_name: &str) -> Option<PathBuf>Expand description
This is a helper function to read the settings directory of the current user depending on the operating system.
It adds the app_name at the end of the path.